@@ -55,6 +55,11 @@ class Account(Resource):
         """The unique id of the billing code that is the default for discovered resources"""
         return self.__default_budget
 
+    @lazy_property
+    def dns_automation(self):
+        """Does this account subscribe to dns_automation?"""
+        return self.__dns_automation
+
     @lazy_property
     def name(self):
         """`str` - User-friendly name used to identify the account"""
