@@ -85,6 +85,15 @@ class Server(Resource):
     def machine_image(self, m):
         self.__machine_image = {u'machine_image_id': m}
 
+    @lazy_property
+    def vlan(self):
+        """`list` - The vlan to assign/assigned to the server"""
+        return self.__vlan
+
+    @vlan.setter
+    def vlan(self, v):
+        self.__vlan = {u'vlan_id': v}
+
     @lazy_property
     def firewalls(self):
         """`list` - The firewalls to assign/assigned to the server"""
@@ -208,6 +217,11 @@ class Server(Resource):
         """`str` - The time the server automatically pauses."""
         return self.__pause_after
 
+    @lazy_property
+    def environment(self):
+        """`str` - The environment. Possibly related to configuration management."""
+        return self.__environment
+
     @property
     def keypair(self):
         """`str` - The keypair to assign
@@ -281,7 +295,7 @@ class Server(Resource):
         :returns: int -- The job id of the launch request
         :raises: :class:`ServerLaunchException`, :class:`mixcoatl.decorators.validations.ValidationException`
         """
-        optional_attrs = ['firewalls', 'keypair', 'label']
+        optional_attrs = ['vlan','firewalls', 'keypair', 'label']
         if self.server_id is not None:
             raise ServerLaunchException('Cannot launch an already running server: %s' % self.server_id)
 
@@ -292,6 +306,7 @@ class Server(Resource):
                         'machineImage': camel_keys(self.machine_image),
                         'description': self.description,
                         'name': self.name,
+                        'vlan': camel_keys(self.vlan),
                         'dataCenter': camel_keys(self.data_center)
                     }]}
 
